@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher::GenericExecutor;
 {
-  $App::PerlWatcher::Watcher::GenericExecutor::VERSION = '0.16_2'; # TRIAL
+  $App::PerlWatcher::Watcher::GenericExecutor::VERSION = '0.18_2'; # TRIAL
 }
 # ABSTRACT: Watches for the output of execution of arbitrary command.
 
@@ -10,7 +10,8 @@ use warnings;
 
 use AnyEvent;
 use AnyEvent::Util;
-use Devel::Comments;
+use Smart::Comments -ENV;
+use IPC::Cmd qw/run/;
 use Moo;
 use POSIX qw(SIGKILL);
 
@@ -22,6 +23,7 @@ with qw/App::PerlWatcher::Watcher/;
 
 
 
+
 has 'command' => ( is => 'ro', required => 1 );
 
 
@@ -108,29 +110,23 @@ sub build_watcher_guard {
         after    => 0,
         interval => $self->frequency,
         cb       => sub {
+            $self->poll_callback->($self);
             my $output;
-            my $pid;
             my $timeout = $self->timeout;
-            my $cv_cmd = run_cmd
-                [$self->command, @{ $self->arguments }],
-                ">"  => \$output,
-                '$$' => \$pid;
-            my $timer; $timer = AnyEvent->timer(
-                after => $timeout,
-                cb    => sub {
-                    $output = "timeout($timeout)";
-                    $cv_cmd->send(1);
-                    undef $cv_cmd;
-                    kill SIGKILL, $pid;
-                },
-            );
-            $cv_cmd->cb(
-                sub {
-                    my $success = !shift->recv;
-                    undef $timer;
-                    $self->callback_proxy->($success, $output);
-                }
-            );
+            my $cv_cmd; $cv_cmd = fork_call {
+				my ($success, $buffer);
+				eval {
+					$success = run(
+						command => [$self->command, @{ $self->arguments }], 
+						timeout => $timeout,
+						buffer  => \$buffer);
+				};
+				($success, $success ? $buffer : $@);
+			} sub {
+				my ($success, $output) = @_;
+				undef $cv_cmd;
+				$self->callback_proxy->($success, $output);
+			};
         });
     return $guard;
 };
@@ -147,7 +143,7 @@ App::PerlWatcher::Watcher::GenericExecutor - Watches for the output of execution
 
 =head1 VERSION
 
-version 0.16_2
+version 0.18_2
 
 =head1 SYNOPSIS
 
@@ -223,6 +219,15 @@ If no is applied, the default status level is 'notice'.
 That closure actully processes the output from command
 and invokes actual callback with Status and EventItems
 
+=head1 Win32 NOTES
+
+Currently, to execute the external program and capture it's output
+the IPC::Cmd::run is used. Unfortunatly, due to limitations of
+alarm function implementation on Windows.
+
+May be there would be some Windows guy, who will implement that
+via Win32::Job?
+
 =head1 AUTHOR
 
 Ivan Baidakou <dmol@gmx.com>
